package com.example.appodeal;

import android.app.Activity;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.PluginRegistry.Registrar;
import com.appodeal.ads.Appodeal;
import com.appodeal.ads.RewardedVideoCallbacks;

/** AppodealPlugin */
public class AppodealPlugin implements MethodCallHandler , RewardedVideoCallbacks {
  private final Registrar registrar;
  static MethodChannel channel;
  static Activity activity;

    private AppodealPlugin(Registrar registrar) {
        this.registrar = registrar;   
    }


    private AudioRecorderPlugin(Registrar registrar){
    this.registrar = registrar;
  }


  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  public static void registerWith(Registrar registrar) {
        channel = new MethodChannel(registrar.messenger(), "appodeal");
        activity = registrar.activity();
        AppodealPlugin plugin = new AppodealPlugin(registrar);
        channel.setMethodCallHandler(plugin);
        Appodeal.setRewardedVideoCallbacks(plugin);
  }

  @Override
  public void onMethodCall( MethodCall call, Result result) {
    //Activity activity = registrar.activity();
    if (activity == null) {
      result.error("no_activity", "appodeal plugin requires a foreground activity", null);
      return;
    }
    if (call.method.equals("initialize")) {
      String appKey = call.argument("appKey");
      List<Integer> types = call.argument("types");
      int type = Appodeal.NONE;
      for (int type2 : types) {
        type = type | this.appodealAdType(type2);
      }
      Appodeal.initialize(activity, appKey, type);
      result.success(Boolean.TRUE);
    } else if (call.method.equals("showInterstitial")) {
      Appodeal.show(activity, Appodeal.INTERSTITIAL);
      result.success(Boolean.TRUE);
    } else if (call.method.equals("showRewardedVideo")) {
      Appodeal.show(activity, Appodeal.REWARDED_VIDEO);
      result.success(Boolean.TRUE);
    } else if (call.method.equals("isLoaded")) {
      int type = call.argument("type");
      int adType = this.appodealAdType(type);
      result.success(Appodeal.isLoaded(adType));
    } else {
      result.notImplemented();
    }
  }

  private int appodealAdType(int innerType) {
    switch (innerType) {
      case 0:
        return Appodeal.INTERSTITIAL;
      case 1:
        return Appodeal.NON_SKIPPABLE_VIDEO;
      case 2:
        return Appodeal.BANNER;
      case 3:
        return Appodeal.NATIVE;
      case 4:
        return Appodeal.REWARDED_VIDEO;
      case 5:
        return Appodeal.MREC;
    }
    return Appodeal.INTERSTITIAL;
  }

  private Map<String, Object> argumentsMap(Object... args) {
    Map<String, Object> arguments = new HashMap<>();
    for (int i = 0; i < args.length; i += 2) arguments.put(args[i].toString(), args[i + 1]);
    return arguments;
  }

  // Appodeal Rewarded Video Callbacks

  @Override
  public void onRewardedVideoLoaded(boolean b) {
    channel.invokeMethod("onRewardedVideoLoaded", argumentsMap());
  }

  @Override
  public void onRewardedVideoFailedToLoad() {
    channel.invokeMethod("onRewardedVideoFailedToLoad", argumentsMap());
  }

  @Override
  public void onRewardedVideoShown() {
    channel.invokeMethod("onRewardedVideoPresent", argumentsMap());
  }

  @Override
  public void onRewardedVideoShowFailed() {

  }

  @Override
  public void onRewardedVideoFinished(double v, String s) {
    channel.invokeMethod("onRewardedVideoFinished", argumentsMap());
  }

  @Override
  public void onRewardedVideoClosed(boolean b) {
    channel.invokeMethod("onRewardedVideoWillDismiss", argumentsMap());
  }

  @Override
  public void onRewardedVideoExpired() {

  }

  @Override
  public void onRewardedVideoClicked() {

  }


}
